@@ -1,5 +1,5 @@
 /* support.c - Support functions for gifsicle.
-   Copyright (C) 1997-2019 Eddie Kohler, ekohler@gmail.com
+   Copyright (C) 1997-2021 Eddie Kohler, ekohler@gmail.com
    This file is part of gifsicle.
 
    Gifsicle is free software. It is distributed under the GNU Public License,
@@ -235,7 +235,7 @@ Whole-GIF options: Also --no-OPTION.\n\
                                 be 'web', 'gray', 'bw', or a GIF file.\n\n");
   printf("\
 Report bugs to <ekohler@gmail.com>.\n\
-Too much information? Try '%s --help | more'.\n", program_name);
+Too much information? Try '%s --help | less'.\n", program_name);
 #ifdef GIF_UNGIF
   printf("\
 This version of Gifsicle writes uncompressed GIFs, which can be far larger\n\
@@ -1104,10 +1104,11 @@ find_color_or_error(Gif_Color *color, Gif_Stream *gfs, Gif_Image *gfi,
 {
   Gif_Colormap *gfcm = gfs->global;
   int index;
-  if (gfi && gfi->local) gfcm = gfi->local;
+  if (gfi && gfi->local)
+    gfcm = gfi->local;
 
   if (color->haspixel == 2) {   /* have pixel value, not color */
-    if (color->pixel < (uint32_t)gfcm->ncol)
+    if (!gfcm || color->pixel < (uint32_t)gfcm->ncol)
       return color->pixel;
     else {
       if (color_context)
@@ -1116,7 +1117,7 @@ find_color_or_error(Gif_Color *color, Gif_Stream *gfs, Gif_Image *gfi,
     }
   }
 
-  index = Gif_FindColor(gfcm, color);
+  index = gfcm ? Gif_FindColor(gfcm, color) : -1;
   if (index < 0 && color_context)
     lwarning(gfs->landmark, "%s color not in colormap", color_context);
   return index;
@@ -1464,7 +1465,8 @@ static void mark_used_background_color(Gt_Frame* fr) {
             || gfi->top != 0
             || gfi->width != gfs->screen_width
             || gfi->height != gfs->screen_height)
-        && gfs->global && gfs->background < gfs->global->ncol)
+        && gfs->global
+        && gfs->background < gfs->global->ncol)
         gfs->global->col[gfs->background].haspixel |= 1;
 }
 
